@@ -48,7 +48,7 @@
 
 // LibKDcraw includes. 
  
-#include <libkdcraw/rawfiles.h> 
+#include <libkdcraw/dcrawbinary.h>
  
 // Local includes.
 
@@ -366,7 +366,7 @@ void AlbumFileTip::updateText()
         }
 
         QSize   dims;
-        QString rawFilesExt(raw_file_extentions);
+        QString rawFilesExt(KDcrawIface::DcrawBinary::instance()->rawFiles());
         QString ext = fileInfo.extension(false).upper();
 
         if (!ext.isEmpty() && rawFilesExt.upper().contains(ext))
