@@ -7,6 +7,7 @@
  * Description : Albums folder view.
  *
  * Copyright (C) 2005-2006 by Joern Ahrens <joern.ahrens@kdemail.net>
+ * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -62,7 +63,6 @@
 #include "albumsettings.h"
 #include "thumbnailjob.h"
 #include "thumbnailsize.h"
-#include "albumpropsedit.h"
 #include "folderitem.h"
 #include "cameraui.h"
 #include "dio.h"
@@ -82,12 +82,9 @@ extern "C"
 namespace Digikam
 {
 
-//-----------------------------------------------------------------------------
-// AlbumFolderViewItem
-//-----------------------------------------------------------------------------
-
 class AlbumFolderViewItem : public FolderItem
 {
+
 public:
 
     AlbumFolderViewItem(QListView *parent, PAlbum *album);
@@ -97,18 +94,24 @@ public:
     AlbumFolderViewItem(QListViewItem* parent, const QString& name,
                         int year, int month);
 
-    PAlbum* getAlbum() const;
-    int id() const;
-    bool isGroupItem() const;
-
-    int compare(QListViewItem *i, int col, bool ascending) const;
-
+    PAlbum* album() const;
+    int     id() const;
+    bool    isGroupItem() const;
+    int     compare(QListViewItem *i, int col, bool ascending) const;
+    void    refresh();
+    void    setOpen(bool o);
+    void    setCount(int count);
+    int     count();
+    
 private:
 
-    PAlbum *m_album;
+    bool    m_groupItem;
+
+    int     m_count;
     int     m_year;
     int     m_month;
-    bool    m_groupItem;
+    
+    PAlbum *m_album;
 };
 
 AlbumFolderViewItem::AlbumFolderViewItem(QListView *parent, PAlbum *album)
@@ -117,6 +120,7 @@ AlbumFolderViewItem::AlbumFolderViewItem(QListView *parent, PAlbum *album)
     setDragEnabled(true);
     m_album     = album;
     m_groupItem = false;
+    m_count     = 0;
 }
 
 AlbumFolderViewItem::AlbumFolderViewItem(QListViewItem *parent, PAlbum *album)
@@ -125,20 +129,57 @@ AlbumFolderViewItem::AlbumFolderViewItem(QListViewItem *parent, PAlbum *album)
     setDragEnabled(true);
     m_album     = album;
     m_groupItem = false;
-/*    setText(0, album->title() + QString(" (%1)")
-            .arg(AlbumManager::instance()->albumDB()->getItemNamesInAlbum(album->id()).count()));*/
+    m_count     = 0;
 }
 
 // special group item (collection/dates)
 AlbumFolderViewItem::AlbumFolderViewItem(QListViewItem* parent, const QString& name,
                                          int year, int month)
-                   : FolderItem(parent, name, true),
-                     m_album(0), m_year(year), m_month(month), m_groupItem(true)
+                   : FolderItem(parent, name, true)
 {
-    setDragEnabled(false);
+    m_album     = 0;
+    m_year      = year;
+    m_month     = month;
+    m_groupItem = true;
+    m_count     = 0;
 }
 
-PAlbum* AlbumFolderViewItem::getAlbum() const
+void AlbumFolderViewItem::refresh()
+{
+    if (!m_album) return;
+    
+    if (AlbumSettings::instance()->getShowFolderTreeViewItemsCount() &&
+        dynamic_cast<AlbumFolderViewItem*>(parent()))
+    {
+        if (isOpen())
+            setText(0, QString("%1 (%2)").arg(m_album->title()).arg(m_count));
+        else
+        {
+            int countRecursive = m_count;
+            AlbumIterator it(m_album);
+            while ( it.current() )
+            {
+                AlbumFolderViewItem *item = (AlbumFolderViewItem*)it.current()->extraData(listView());
+                if (item)
+                    countRecursive += item->count();
+                ++it;
+            }
+            setText(0, QString("%1 (%2)").arg(m_album->title()).arg(countRecursive));
+        }
+    }
+    else
+    {
+        setText(0, m_album->title());
+    }
+}
+
+void AlbumFolderViewItem::setOpen(bool o)
+{
+    QListViewItem::setOpen(o);
+    refresh();
+}
+
+PAlbum* AlbumFolderViewItem::album() const
 {
     return m_album;
 }
@@ -188,10 +229,18 @@ int AlbumFolderViewItem::compare(QListViewItem *i, int col, bool ascending) cons
         return -1;
 }
 
+void AlbumFolderViewItem::setCount(int count)
+{
+    m_count = count;
+    refresh();
+}
 
-//-----------------------------------------------------------------------------
-// AlbumFolderViewPriv
-//-----------------------------------------------------------------------------
+int AlbumFolderViewItem::count()
+{
+    return m_count;
+}
+
+// -----------------------------------------------------------------------------
 
 class AlbumFolderViewPriv
 {
@@ -208,10 +257,6 @@ public:
     QValueList<AlbumFolderViewItem*>  groupItems;
 };
 
-//-----------------------------------------------------------------------------
-// AlbumFolderView
-//-----------------------------------------------------------------------------
-
 AlbumFolderView::AlbumFolderView(QWidget *parent)
                : FolderView(parent, "AlbumFolderView")
 {
@@ -242,6 +287,9 @@ AlbumFolderView::AlbumFolderView(QWidget *parent)
     connect(d->albumMan, SIGNAL(signalAlbumRenamed(Album*)),
             this, SLOT(slotAlbumRenamed(Album*)));
 
+    connect(d->albumMan, SIGNAL(signalPAlbumsDirty(const QMap<int, int>&)),
+            this, SLOT(slotRefresh(const QMap<int, int>&)));
+
     AlbumThumbnailLoader *loader = AlbumThumbnailLoader::instance();
 
     connect(loader, SIGNAL(signalThumbnail(Album *, const QPixmap&)),
@@ -268,7 +316,7 @@ AlbumFolderView::~AlbumFolderView()
     delete d;
 }
 
-void AlbumFolderView::slotFolderFilterChanged(const QString& filter)
+void AlbumFolderView::slotTextFolderFilterChanged(const QString& filter)
 {
     QString search = filter.lower();
 
@@ -333,7 +381,7 @@ void AlbumFolderView::slotFolderFilterChanged(const QString& filter)
         }
     }
 
-    emit signalFolderFilterMatch(atleastOneMatch);
+    emit signalTextFolderFilterMatch(atleastOneMatch);
 }
 
 void AlbumFolderView::slotAlbumAdded(Album *album)
@@ -406,9 +454,7 @@ void AlbumFolderView::slotAlbumRenamed(Album *album)
 
     AlbumFolderViewItem* item = (AlbumFolderViewItem*) palbum->extraData(this);
     if(item)
-    {
-        item->setText(0, palbum->title());
-    }
+        item->refresh();
 }
 
 void AlbumFolderView::slotAlbumsCleared()
@@ -513,7 +559,7 @@ void AlbumFolderView::slotSelectionChanged()
         return;
     }
 
-    d->albumMan->setCurrentAlbum(albumitem->getAlbum());
+    d->albumMan->setCurrentAlbum(albumitem->album());
 }
 
 void AlbumFolderView::slotContextMenu(QListViewItem *listitem, const QPoint &, int)
@@ -527,7 +573,7 @@ void AlbumFolderView::slotContextMenu(QListViewItem *listitem, const QPoint &, i
     popmenu.insertItem(SmallIcon("albumfolder-new"), i18n("New Album..."), 10);
 
     AlbumFolderViewItem *item = dynamic_cast<AlbumFolderViewItem*>(listitem);
-    if (item && !item->getAlbum())
+    if (item && !item->album())
     {
         // if collection/date return
         return;
@@ -631,7 +677,7 @@ void AlbumFolderView::slotContextMenu(QListViewItem *listitem, const QPoint &, i
         case 13:
         {
             QString err;
-            d->albumMan->updatePAlbumIcon(item->getAlbum(), 0, err);
+            d->albumMan->updatePAlbumIcon(item->album(), 0, err);
             break;
         }
         case 14:
@@ -683,7 +729,7 @@ void AlbumFolderView::albumNew(AlbumFolderViewItem *item)
     if(!item)
         parent = d->albumMan->findPAlbum(0);
     else
-        parent = item->getAlbum();
+        parent = item->album();
 
     if (!parent)
         return;
@@ -738,7 +784,7 @@ void AlbumFolderView::albumDelete()
 
 void AlbumFolderView::albumDelete(AlbumFolderViewItem *item)
 {
-    PAlbum *album = item->getAlbum();
+    PAlbum *album = item->album();
 
     if(!album || album->isRoot())
         return;
@@ -800,7 +846,7 @@ void AlbumFolderView::albumRename()
 
 void AlbumFolderView::albumRename(AlbumFolderViewItem* item)
 {
-    PAlbum *album = item->getAlbum();
+    PAlbum *album = item->album();
 
     if (!album)
         return;
@@ -842,7 +888,7 @@ void AlbumFolderView::albumEdit()
 
 void AlbumFolderView::albumEdit(AlbumFolderViewItem* item)
 {
-    PAlbum *album = item->getAlbum();
+    PAlbum *album = item->album();
 
     if (!album)
         return;
@@ -892,7 +938,7 @@ QDragObject* AlbumFolderView::dragObject()
     if(!item)
         return 0;
 
-    PAlbum *album = item->getAlbum();
+    PAlbum *album = item->album();
     if(album->isRoot())
         return 0;
 
@@ -925,7 +971,7 @@ bool AlbumFolderView::acceptDrop(const QDropEvent *e) const
                     return false;
     
                 // Dragging a parent on its child makes no sense
-                if(itemDrag && itemDrag->getAlbum()->isAncestorOf(itemDrop->getAlbum()))
+                if(itemDrag && itemDrag->album()->isAncestorOf(itemDrop->album()))
                     return false;
     
                 return true;
@@ -1008,7 +1054,7 @@ void AlbumFolderView::contentsDropEvent(QDropEvent *e)
 
             if(id == 10)
             {
-                PAlbum *album = itemDrag->getAlbum();
+                PAlbum *album = itemDrag->album();
                 PAlbum *destAlbum;
                 if(!itemDrop)
                 {
@@ -1018,7 +1064,7 @@ void AlbumFolderView::contentsDropEvent(QDropEvent *e)
                 else
                 {
                     // move dragItem below dropItem
-                    destAlbum = itemDrop->getAlbum();
+                    destAlbum = itemDrop->album();
                 }
                 KIO::Job* job = DIO::move(album->kurl(), destAlbum->kurl());
                 connect(job, SIGNAL(result(KIO::Job*)),
@@ -1033,7 +1079,7 @@ void AlbumFolderView::contentsDropEvent(QDropEvent *e)
 
             if (itemDrop->isGroupItem())
             {
-                PAlbum *album = itemDrag->getAlbum();
+                PAlbum *album = itemDrag->album();
                 if (!album)
                     return;
 
@@ -1050,7 +1096,7 @@ void AlbumFolderView::contentsDropEvent(QDropEvent *e)
         if (!itemDrop)
             return;
 
-        PAlbum *destAlbum = itemDrop->getAlbum();
+        PAlbum *destAlbum = itemDrop->album();
 
         KURL::List      urls;
         KURL::List      kioURLs;
@@ -1182,7 +1228,7 @@ void AlbumFolderView::contentsDropEvent(QDropEvent *e)
 
     if(CameraItemListDrag::canDecode(e))
     {
-        Album *album = dynamic_cast<Album*>(itemDrop->getAlbum());
+        Album *album = dynamic_cast<Album*>(itemDrop->album());
         if (!album) return;
         
         CameraUI *ui = dynamic_cast<CameraUI*>(e->source());
@@ -1221,7 +1267,7 @@ void AlbumFolderView::contentsDropEvent(QDropEvent *e)
         PAlbum* destAlbum = 0;
 
         if (itemDrop)
-            destAlbum = itemDrop->getAlbum();
+            destAlbum = itemDrop->album();
         else
             destAlbum = d->albumMan->findPAlbum(0);
 
@@ -1310,7 +1356,7 @@ void AlbumFolderView::albumImportFolder()
     if(selectedItem())
     {
         AlbumFolderViewItem *folderItem = dynamic_cast<AlbumFolderViewItem*>(selectedItem());
-        Album *album = folderItem->getAlbum();
+        Album *album = folderItem->album();
         if (album && album->type() == Album::PHYSICAL)
         {
             parent = dynamic_cast<PAlbum*>(album);
@@ -1487,7 +1533,7 @@ void AlbumFolderView::reparentItem(AlbumFolderViewItem* folderItem)
     if (!folderItem)
         return;
 
-    PAlbum* album = folderItem->getAlbum();
+    PAlbum* album = folderItem->album();
     if (!album || album->isRoot())
         return;
 
@@ -1536,4 +1582,40 @@ void AlbumFolderView::clearEmptyGroupItems()
     }
 }
 
+void AlbumFolderView::refresh()
+{
+    QListViewItemIterator it(this);
+    
+    while (it.current())
+    {
+        AlbumFolderViewItem* item = dynamic_cast<AlbumFolderViewItem*>(*it);
+        if (item)
+            item->refresh();
+        ++it;
+    }
+}
+
+void AlbumFolderView::slotRefresh(const QMap<int, int>& albumsStatMap)
+{
+    QListViewItemIterator it(this);
+    
+    while (it.current())
+    {
+        AlbumFolderViewItem* item = dynamic_cast<AlbumFolderViewItem*>(*it);
+        if (item)
+        {
+            if (item->album())
+            {
+                int id = item->id();
+                QMap<int, int>::const_iterator it2 = albumsStatMap.find(id);
+                if ( it2 != albumsStatMap.end() )
+                    item->setCount(it2.data());
+            }
+        }
+        ++it;
+    }
+
+    refresh();
+}
+
 }  // namespace Digikam
