@@ -6,7 +6,8 @@
  * Date        : 2004-06-15
  * Description : Albums manager interface.
  * 
- * Copyright (C) 2004 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2004-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -30,11 +31,11 @@ extern "C"
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
-#include <locale.h>
 }
 
 // C++ includes.
 
+#include <clocale>
 #include <cstdlib>
 #include <cstdio>
 #include <cerrno> 
@@ -70,6 +71,7 @@ extern "C"
 #include "dio.h"
 #include "albumsettings.h"
 #include "scanlib.h"
+#include "splashscreen.h"
 #include "upgradedb_sqlite2tosqlite3.h"
 #include "albummanager.h"
 #include "albummanager.moc"
@@ -82,31 +84,48 @@ typedef QIntDict<Album>  AlbumIntDict;
 
 class AlbumManagerPriv
 {
+
 public:
+
+    AlbumManagerPriv()
+    {
+        db            = 0;
+        dateListJob   = 0;
+        albumListJob  = 0;
+        tagListJob    = 0;
+        rootPAlbum    = 0;
+        rootTAlbum    = 0;
+        rootDAlbum    = 0;
+        rootSAlbum    = 0;
+        itemHandler   = 0;
+        currentAlbum  = 0;
+        dirWatch      = 0;
+        changed       = false;
+    }
     
-    AlbumDB          *db;
-    AlbumItemHandler *itemHandler;
+    bool              changed;
     
     QString           libraryPath;
+    QStringList       dirtyAlbums;
+
+    KDirWatch        *dirWatch;
+
+    KIO::TransferJob *albumListJob;
+    KIO::TransferJob *dateListJob;
+    KIO::TransferJob *tagListJob;
 
     PAlbum           *rootPAlbum;
     TAlbum           *rootTAlbum;
     DAlbum           *rootDAlbum;
     SAlbum           *rootSAlbum;
 
-    bool              changed;
-    
     PAlbumDict        pAlbumDict;
     AlbumIntDict      albumIntDict;
 
     Album            *currentAlbum;
-
-    KIO::TransferJob *dateListJob;
-
-    KDirWatch        *dirWatch;
-    QStringList       dirtyAlbums;
+    AlbumDB          *db;
+    AlbumItemHandler *itemHandler;
 };
-    
 
 AlbumManager* AlbumManager::m_instance = 0;
 
@@ -117,24 +136,10 @@ AlbumManager* AlbumManager::instance()
 
 AlbumManager::AlbumManager()
 {
-    m_instance    = this;
+    m_instance = this;
 
     d = new AlbumManagerPriv;
-    
     d->db = new AlbumDB;
-    d->dateListJob = 0;
-
-    d->rootPAlbum = 0;
-    d->rootTAlbum = 0;
-    d->rootDAlbum = 0;
-    d->rootSAlbum = 0;
-
-    d->itemHandler  = 0;
-    d->currentAlbum = 0;
-
-    d->dirWatch = 0;
-
-    d->changed  = false;
 }
 
 AlbumManager::~AlbumManager()
@@ -145,6 +150,18 @@ AlbumManager::~AlbumManager()
         d->dateListJob = 0;
     }
     
+    if (d->albumListJob)
+    {
+        d->albumListJob->kill();
+        d->albumListJob = 0;
+    }
+    
+    if (d->tagListJob)
+    {
+        d->tagListJob->kill();
+        d->tagListJob = 0;
+    }
+
     delete d->rootPAlbum;
     delete d->rootTAlbum;
     delete d->rootDAlbum;
@@ -158,13 +175,12 @@ AlbumManager::~AlbumManager()
     m_instance = 0;
 }
 
-
 AlbumDB* AlbumManager::albumDB()
 {
     return d->db;    
 }
 
-void AlbumManager::setLibraryPath(const QString& path)
+void AlbumManager::setLibraryPath(const QString& path, SplashScreen *splash)
 {
     QString cleanPath = QDir::cleanDirPath(path);
     
@@ -179,6 +195,18 @@ void AlbumManager::setLibraryPath(const QString& path)
         d->dateListJob = 0;
     }
 
+    if (d->albumListJob)
+    {
+        d->albumListJob->kill();
+        d->albumListJob = 0;
+    }
+    
+    if (d->tagListJob)
+    {
+        d->tagListJob->kill();
+        d->tagListJob = 0;
+    }
+
     delete d->dirWatch;
     d->dirWatch = 0;
     d->dirtyAlbums.clear();
@@ -264,8 +292,8 @@ void AlbumManager::setLibraryPath(const QString& path)
         // buttons that denote the actions directly, i.e.:  ["Ignore and Continue"]  ["Adjust locale"]
         int result =
             KMessageBox::warningYesNo(0,
-                                      i18n("Your locale has changed from the previous time "
-                                           "this album was opened.\n"
+                                      i18n("Your locale has changed since this album "
+                                           "was last opened.\n"
                                            "Old Locale : %1, New Locale : %2\n"
                                            "This can cause unexpected problems. "
                                            "If you are sure that you want to "
@@ -284,7 +312,10 @@ void AlbumManager::setLibraryPath(const QString& path)
 
     if (!upgradeDB_Sqlite2ToSqlite3(d->libraryPath))
     {
-        KMessageBox::error(0, i18n("Failed to update old Database to new Database format"));
+        KMessageBox::error(0, i18n("Failed to update the old Database to the new Database format\n"
+                                   "This error can happen if the Album Path '%1' does not exist or is write-protected.\n"
+                                   "If you have moved your photo collection, you need to adjust the 'Album Path' in digikam's configuration file.")
+                                   .arg(d->libraryPath));
         exit(0);
     }
     
@@ -295,7 +326,7 @@ void AlbumManager::setLibraryPath(const QString& path)
     if (config->readBoolEntry("Scan At Start", true) ||
         d->db->getSetting("Scanned").isEmpty())
     {
-        ScanLib sLib;
+        ScanLib sLib(splash);
         sLib.startScan();
     }
 }
@@ -313,7 +344,17 @@ void AlbumManager::startScan()
     
     d->dirWatch = new KDirWatch(this);
     connect(d->dirWatch, SIGNAL(dirty(const QString&)),
-            SLOT(slotDirty(const QString&)));
+            this, SLOT(slotDirty(const QString&)));
+    
+    KDirWatch::Method m = d->dirWatch->internalMethod();
+    QString mName("FAM");
+    if (m == KDirWatch::DNotify)
+        mName = QString("DNotify");
+    else if (m == KDirWatch::Stat)
+        mName = QString("Stat");
+    else if (m == KDirWatch::INotify)
+        mName = QString("INotify");
+    DDebug() << "KDirWatch method = " << mName << endl;
 
     d->dirWatch->addDir(d->libraryPath);
 
@@ -428,7 +469,7 @@ void AlbumManager::scanPAlbums()
         if (!parent)
         {
             DWarning() << k_funcinfo <<  "Could not find parent with url: "
-                        << purl << " for: " << info.url << endl;
+                       << purl << " for: " << info.url << endl;
             continue;
         }
 
@@ -443,7 +484,41 @@ void AlbumManager::scanPAlbums()
         d->dirWatch->addDir(album->folderPath());
 
         insertPAlbum(album);
-    } 
+    }
+
+    if (!AlbumSettings::instance()->getShowFolderTreeViewItemsCount())
+        return;
+        
+    // List albums using kioslave
+
+    if (d->albumListJob)
+    {
+        d->albumListJob->kill();
+        d->albumListJob = 0;
+    }
+    
+    KURL u;
+    u.setProtocol("digikamalbums");
+    u.setPath("/");
+
+    QByteArray ba;
+    QDataStream ds(ba, IO_WriteOnly);
+    ds << d->libraryPath;
+    ds << KURL();
+    ds << AlbumSettings::instance()->getAllFileFilter();
+    ds << 0; // getting dimensions (not needed here)
+    ds << 0; // recursive sub-album (not needed here)
+    ds << 0; // recursive sub-tags (not needed here)
+        
+    d->albumListJob = new KIO::TransferJob(u, KIO::CMD_SPECIAL,
+                                           ba, QByteArray(), false);
+    d->albumListJob->addMetaData("folders", "yes");
+
+    connect(d->albumListJob, SIGNAL(result(KIO::Job*)),
+            this, SLOT(slotAlbumsJobResult(KIO::Job*)));
+
+    connect(d->albumListJob, SIGNAL(data(KIO::Job*, const QByteArray&)),
+            this, SLOT(slotAlbumsJobData(KIO::Job*, const QByteArray&)));
 }
 
 void AlbumManager::scanTAlbums()
@@ -559,6 +634,40 @@ void AlbumManager::scanTAlbums()
         // also insert it in the map we are doing lookup of parent tags
         tmap.insert(info.id, album);
     }
+
+    if (!AlbumSettings::instance()->getShowFolderTreeViewItemsCount())
+        return;
+        
+    // List tags using kioslave
+
+    if (d->tagListJob)
+    {
+        d->tagListJob->kill();
+        d->tagListJob = 0;
+    }
+    
+    KURL u;
+    u.setProtocol("digikamtags");
+    u.setPath("/");
+
+    QByteArray ba;
+    QDataStream ds(ba, IO_WriteOnly);
+    ds << d->libraryPath;
+    ds << KURL();
+    ds << AlbumSettings::instance()->getAllFileFilter();
+    ds << 0; // getting dimensions (not needed here)
+    ds << 0; // recursive sub-album (not needed here)
+    ds << 0; // recursive sub-tags (not needed here)
+        
+    d->tagListJob = new KIO::TransferJob(u, KIO::CMD_SPECIAL,
+                                         ba, QByteArray(), false);
+    d->tagListJob->addMetaData("folders", "yes");
+
+    connect(d->tagListJob, SIGNAL(result(KIO::Job*)),
+            this, SLOT(slotTagsJobResult(KIO::Job*)));
+
+    connect(d->tagListJob, SIGNAL(data(KIO::Job*, const QByteArray&)),
+            this, SLOT(slotTagsJobData(KIO::Job*, const QByteArray&)));
 }
 
 void AlbumManager::scanSAlbums()
@@ -625,10 +734,10 @@ void AlbumManager::scanDAlbums()
     d->dateListJob->addMetaData("folders", "yes");
 
     connect(d->dateListJob, SIGNAL(result(KIO::Job*)),
-            this, SLOT(slotResult(KIO::Job*)));
+            this, SLOT(slotDatesJobResult(KIO::Job*)));
 
     connect(d->dateListJob, SIGNAL(data(KIO::Job*, const QByteArray&)),
-            this, SLOT(slotData(KIO::Job*, const QByteArray&)));
+            this, SLOT(slotDatesJobData(KIO::Job*, const QByteArray&)));
 }
 
 AlbumList AlbumManager::allPAlbums() const
@@ -897,7 +1006,7 @@ bool AlbumManager::renamePAlbum(PAlbum* album, const QString& newName,
 
     QString oldURL = album->url();
     
-    KURL u = KURL(album->folderPath()).upURL();
+    KURL u = KURL::fromPathOrURL(album->folderPath()).upURL();
     u.addPath(newName);
     u.cleanPath();
 
@@ -1315,7 +1424,53 @@ void AlbumManager::refreshItemHandler(const KURL::List& itemList)
         d->itemHandler->refreshItems(itemList);
 }
 
-void AlbumManager::slotResult(KIO::Job* job)
+void AlbumManager::slotAlbumsJobResult(KIO::Job* job)
+{
+    d->albumListJob = 0;
+
+    if (job->error())
+    {
+        DWarning() << k_funcinfo << "Failed to list albums" << endl;
+        return;
+    }
+}
+
+void AlbumManager::slotAlbumsJobData(KIO::Job*, const QByteArray& data)
+{
+    if (data.isEmpty())
+        return;
+
+    QMap<int, int> albumsStatMap;
+    QDataStream ds(data, IO_ReadOnly);
+    ds >> albumsStatMap;
+
+    emit signalPAlbumsDirty(albumsStatMap);
+}
+
+void AlbumManager::slotTagsJobResult(KIO::Job* job)
+{
+    d->tagListJob = 0;
+
+    if (job->error())
+    {
+        DWarning() << k_funcinfo << "Failed to list tags" << endl;
+        return;
+    }
+}
+
+void AlbumManager::slotTagsJobData(KIO::Job*, const QByteArray& data)
+{
+    if (data.isEmpty())
+        return;
+
+    QMap<int, int> tagsStatMap;
+    QDataStream ds(data, IO_ReadOnly);
+    ds >> tagsStatMap;
+
+    emit signalTAlbumsDirty(tagsStatMap);
+}
+
+void AlbumManager::slotDatesJobResult(KIO::Job* job)
 {
     d->dateListJob = 0;
 
@@ -1324,62 +1479,130 @@ void AlbumManager::slotResult(KIO::Job* job)
         DWarning() << k_funcinfo << "Failed to list dates" << endl;
         return;
     }
-    
+
     emit signalAllDAlbumsLoaded();
 }
 
-
-void AlbumManager::slotData(KIO::Job* , const QByteArray& data)
+void AlbumManager::slotDatesJobData(KIO::Job*, const QByteArray& data)
 {
     if (data.isEmpty())
         return;
 
     // insert all the DAlbums into a qmap for quick access
-    QMap<QDate, DAlbum*> albumMap;
-    
+    QMap<QDate, DAlbum*> mAlbumMap;
+    QMap<int, DAlbum*>   yAlbumMap;
+
     AlbumIterator it(d->rootDAlbum);
     while (it.current())
     {
         DAlbum* a = (DAlbum*)(*it);
-        albumMap.insert(a->date(), a);
+        if (a->range() == DAlbum::Month)
+            mAlbumMap.insert(a->date(), a);
+        else
+            yAlbumMap.insert(a->date().year(), a);
         ++it;
     }
-    
-    QDataStream ds(data, IO_ReadOnly);
-    while (!ds.atEnd())
-    {
-        QDate date;
-        ds >> date;
 
-        // Do we already have this album
-        if (albumMap.contains(date))
+    QMap<QDateTime, int> datesStatMap;
+    QDataStream ds(data, IO_ReadOnly);
+    ds >> datesStatMap;
+
+    QMap<YearMonth, int> yearMonthMap;
+    for ( QMap<QDateTime, int>::iterator it = datesStatMap.begin();
+          it != datesStatMap.end(); ++it )
+    {
+        QMap<YearMonth, int>::iterator it2 = yearMonthMap.find(YearMonth(it.key().date().year(), it.key().date().month()));
+        if ( it2 == yearMonthMap.end() )
         {
-            // already there. remove from map
-            albumMap.remove(date);
+            yearMonthMap.insert( YearMonth(it.key().date().year(), it.key().date().month()), it.data() );
+        }
+        else
+        {
+            yearMonthMap.replace( YearMonth(it.key().date().year(), it.key().date().month()), it2.data() + it.data() );
+        }
+    }
+
+    int year, month;
+    for ( QMap<YearMonth, int>::iterator it = yearMonthMap.begin();
+          it != yearMonthMap.end(); ++it )
+    {
+        year  = it.key().first;
+        month = it.key().second;
+
+        QDate md(year, month, 1);
+
+        // Do we already have this Month album
+        if (mAlbumMap.contains(md))
+        {
+            // already there. remove Month album from map
+            mAlbumMap.remove(md);
+
+            if (yAlbumMap.contains(year))
+            {
+                // already there. remove from map
+                yAlbumMap.remove(year);
+            }
+
             continue;
         }
 
-        // new album. create one
-        DAlbum* album = new DAlbum(date);
-        album->setParent(d->rootDAlbum);
-        d->albumIntDict.insert(album->globalID(), album);
-        emit signalAlbumAdded(album);
+        // Check if Year Album already exist.
+        DAlbum *yAlbum = 0;
+        AlbumIterator it(d->rootDAlbum);
+        while (it.current())
+        {
+            DAlbum* a = (DAlbum*)(*it);
+            if (a->date() == QDate(year, 1, 1) && a->range() == DAlbum::Year)
+            {
+                yAlbum = a;
+                break;
+            }
+            ++it;
+        }
+
+        // If no, create Year album.
+        if (!yAlbum)
+        {
+            yAlbum = new DAlbum(QDate(year, 1, 1), false, DAlbum::Year);
+            yAlbum->setParent(d->rootDAlbum);
+            d->albumIntDict.insert(yAlbum->globalID(), yAlbum);
+            emit signalAlbumAdded(yAlbum);
+        }
+
+        // Create Month album
+        DAlbum *mAlbum = new DAlbum(md);
+        mAlbum->setParent(yAlbum);
+        d->albumIntDict.insert(mAlbum->globalID(), mAlbum);
+        emit signalAlbumAdded(mAlbum);
     }
 
-    // Now the items contained in the map are the ones which
+    // Now the items contained in the maps are the ones which
     // have been deleted. 
-    for (QMap<QDate,DAlbum*>::iterator it = albumMap.begin();
-         it != albumMap.end(); ++it)
+    for (QMap<QDate, DAlbum*>::iterator it = mAlbumMap.begin();
+         it != mAlbumMap.end(); ++it)
     {
         DAlbum* album = it.data();
         emit signalAlbumDeleted(album);
         d->albumIntDict.remove(album->globalID());
         delete album;
     }
+
+    for (QMap<int, DAlbum*>::iterator it = yAlbumMap.begin();
+         it != yAlbumMap.end(); ++it)
+    {
+        DAlbum* album = it.data();
+        emit signalAlbumDeleted(album);
+        d->albumIntDict.remove(album->globalID());
+        delete album;
+    }
+
+    emit signalDAlbumsDirty(yearMonthMap);
+    emit signalDatesMapDirty(datesStatMap);
 }
 
 void AlbumManager::slotDirty(const QString& path)
 {
+    DDebug() << "Noticed file change in directory " << path << endl;
     QString url = QDir::cleanDirPath(path);
     url = QDir::cleanDirPath(url.remove(d->libraryPath));
 
@@ -1389,7 +1612,6 @@ void AlbumManager::slotDirty(const QString& path)
     if (d->dirtyAlbums.contains(url))
         return;
 
-    DDebug() << "Dirty: " << url << endl;
     d->dirtyAlbums.append(url);
 
     if (DIO::running())
@@ -1404,5 +1626,3 @@ void AlbumManager::slotDirty(const QString& path)
 }
 
 }  // namespace Digikam
-
-
