@@ -1,12 +1,14 @@
 /* ============================================================
- * Authors: Renchi Raju <renchi@pooh.tam.uiuc.edu>
- *          Gilles Caulier <caulier dot gilles at gmail dot com> 
- *          Marcel Wiesweg <marcel.wiesweg@gmx.de>
- * Date   : 2005-06-14
+ *
+ * This file is a part of digiKam project
+ * http://www.digikam.org
+ *
+ * Date        : 2005-06-14
  * Description : digiKam 8/16 bits image management API
  *
- * Copyright 2005 by Renchi Raju, Gilles Caulier
- * Copyright 2006-2007 by Gilles Caulier, Marcel Wiesweg 
+ * Copyright (C) 2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2005-2007 by Gilles Caulier <caulier dot gilles at gmail dot com> 
+ * Copyright (C) 2006-2007 by Marcel Wiesweg <marcel.wiesweg@gmx.de>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -38,10 +40,13 @@ extern "C"
 #include <qfileinfo.h>
 #include <qmap.h>
 
+// LibKDcraw includes.
+
+#include <libkdcraw/dcrawbinary.h>
+#include <libkdcraw/kdcraw.h>
+
 // Local includes.
 
-#include "rawfiles.h"
-#include "dcrawiface.h"
 #include "pngloader.h"
 #include "jpegloader.h"
 #include "tiffloader.h"
@@ -67,8 +72,15 @@ DImg::DImg()
 {
 }
 
+DImg::DImg(const QCString& filePath, DImgLoaderObserver *observer,
+           KDcrawIface::RawDecodingSettings rawDecodingSettings)
+    : m_priv(new DImgPrivate)
+{
+    load(filePath, observer, rawDecodingSettings);
+}
+
 DImg::DImg(const QString& filePath, DImgLoaderObserver *observer,
-           RawDecodingSettings rawDecodingSettings)
+           KDcrawIface::RawDecodingSettings rawDecodingSettings)
     : m_priv(new DImgPrivate)
 {
     load(filePath, observer, rawDecodingSettings);
@@ -98,6 +110,34 @@ DImg::DImg(const DImg &image, int w, int h)
     allocateData();
 }
 
+DImg::DImg(const QImage& image)
+    : m_priv(new DImgPrivate)
+{
+    if (!image.isNull())
+    {
+        QImage target = image.convertDepth(32);
+        
+        uint w      = target.width();
+        uint h      = target.height();
+        uchar* data = new uchar[w*h*4];
+        uint*  sptr = (uint*)target.bits();
+        uchar* dptr = data;
+        
+        for (uint i = 0 ; i < w*h ; i++)
+        {
+            dptr[0] = qBlue(*sptr);
+            dptr[1] = qGreen(*sptr);
+            dptr[2] = qRed(*sptr);
+            dptr[3] = qAlpha(*sptr);
+            
+            dptr += 4;
+            sptr++;
+        }
+    
+        putImageData(w, h, false, image.hasAlphaBuffer(), data, false);
+    }
+}
+
 DImg::~DImg()
 {
     if (m_priv->deref())
@@ -234,7 +274,7 @@ void DImg::copyMetaData(const DImgPrivate *src)
     m_priv->attributes   = src->attributes;
     m_priv->embeddedText = src->embeddedText;
 
-    // since qbytearrays are explicitely shared, we need to make sure that they are
+    // since qbytearrays are explicitly shared, we need to make sure that they are
     // detached from any shared references
 
     for (QMap<int, QByteArray>::const_iterator it = src->metaData.begin();
@@ -278,7 +318,7 @@ void DImg::setImageData(bool null, uint width, uint height, bool sixteenBit, boo
 
 
 bool DImg::load(const QString& filePath, DImgLoaderObserver *observer,
-                RawDecodingSettings rawDecodingSettings)
+                KDcrawIface::RawDecodingSettings rawDecodingSettings)
 {
     FORMAT format = fileFormat(filePath);
 
@@ -453,7 +493,7 @@ DImg::FORMAT DImg::fileFormat(const QString& filePath)
         return NONE;
     }
 
-    QString rawFilesExt(raw_file_extentions);
+    QString rawFilesExt(KDcrawIface::DcrawBinary::instance()->rawFiles());
     QString ext = fileInfo.extension(false).upper();
 
     if (!ext.isEmpty())
@@ -494,8 +534,8 @@ DImg::FORMAT DImg::fileFormat(const QString& filePath)
 
     fclose(f);
 
-    DcrawInfoContainer dcrawIdentify;
-    DcrawIface::rawFileIdentify(dcrawIdentify, filePath);
+    KDcrawIface::DcrawInfoContainer dcrawIdentify;
+    KDcrawIface::KDcraw::rawFileIdentify(dcrawIdentify, filePath);
     uchar jpegID[2]    = { 0xFF, 0xD8 };
     uchar tiffBigID[2] = { 0x4D, 0x4D };
     uchar tiffLilID[2] = { 0x49, 0x49 };
@@ -1021,112 +1061,6 @@ void DImg::bitBlend (DColorComposer *composer, const uchar *src, uchar *dest,
 }
 
 
-// This method is inspired from imlib2::__imlib_BlendRGBAToRGB() (blend.c)
-
-void DImg::bitBlend_RGBA2RGB(DImg& region, int x, int y, int w, int h)
-{
-    int tmp;
-
-#define BLEND_COLOR(a, nc, c, cc) \
-    tmp = ((c) - (cc)) * (a); \
-    nc = (cc) + ((tmp + (tmp >> bitsDepth()) + (128*(sixteenBit() ? 256 : 1)) >> bitsDepth()));
-
-#define BLEND(r1, g1, b1, a1, dest) \
-    BLEND_COLOR(a1, dest[2], r1, dest[2]); \
-    BLEND_COLOR(a1, dest[1], g1, dest[1]); \
-    BLEND_COLOR(a1, dest[0], b1, dest[0]);
-
-    if (isNull() || region.sixteenBit() != sixteenBit() ||
-        w <= 0 || h <= 0)
-       {
-           DDebug() << k_funcinfo << " : invalid blending arguments!" << endl;
-           return;
-       }
-
-    // Normalize
-
-    if (x < 0)
-    {
-       // x is negative, so + is -
-       w = w + x;
-       x = 0;
-    }
-
-    if (y < 0)
-    {
-       h = h + y;
-       y = 0;
-    }
-
-    if (w > (int)width())
-       w = width();
-
-    if (h > (int)height())
-       w = height();
-
-    if (!sixteenBit())         // 8 bits image.
-    {
-        uchar  alpha;
-        uchar *pptr;
-        uchar *dst = bits();
-        uchar *src = region.bits();
-    
-        for (int j = y ; j < (y + h) ; j++) 
-        {
-            pptr = &src[ j * width() * 4 ] + x * 4;
-    
-            for (int i = 0 ; i < w ; i++)
-            {
-                alpha = pptr[3];
-    
-                switch (alpha)
-                {
-                    case 0:
-                        break;
-        
-                    default:
-                        BLEND(pptr[2], pptr[1], pptr[0], alpha, dst);
-                        break;
-                }
-                
-                pptr+=4;
-                dst+=4;
-            }
-        }
-    }
-    else                        // 16 bits image.
-    {
-        unsigned short  alpha;
-        unsigned short *pptr;
-        unsigned short *dst = (unsigned short *)bits();
-        unsigned short *src = (unsigned short *)region.bits();
-    
-        for (int j = y ; j < (y + h) ; j++) 
-        {
-            pptr = &src[ j * width() * 4 ] + x * 4;
-    
-            for (int i = 0 ; i < w ; i++)
-            {
-                alpha = pptr[3];
-    
-                switch (alpha)
-                {
-                    case 0:
-                        break;
-        
-                    default:
-                        BLEND(pptr[2], pptr[1], pptr[0], alpha, dst);
-                        break;
-                }
-                
-                pptr+=4;
-                dst+=4;
-            }
-        }
-    }
-}
-
-
 //---------------------------------------------------------------------------------------------------
 // QImage / QPixmap access
 
@@ -1406,7 +1340,7 @@ void DImg::rotate(ANGLE angle)
         uint w  = width();
         uint h  = height();
 
-        uint middle_line = -1;
+        int middle_line = -1;
         if (h % 2)
            middle_line = h / 2;
 
@@ -1431,7 +1365,7 @@ void DImg::rotate(ANGLE angle)
 
                     line1++;
                     line2--;
-                    if (y == middle_line && x * 2 >= w)
+                    if ((int)y == middle_line && x * 2 >= w)
                         break;
                 }
             }
@@ -1458,8 +1392,8 @@ void DImg::rotate(ANGLE angle)
 
                     line1++;
                     line2--;
-                    if (y == middle_line && x * 2 >= w)
-			break;
+                    if ((int)y == middle_line && x * 2 >= w)
+                        break;
                 }
             }
         }
