@@ -1,10 +1,13 @@
 /* ============================================================
- * Authors: F.J. Cruz <fj.cruz@supercable.es>
- *          Gilles Caulier <caulier dot gilles at gmail dot com> 
- * Date   : 2005-11-18
+ *
+ * This file is a part of digiKam project
+ * http://www.digikam.org
+ *
+ * Date        : 2005-11-18
  * Description : a class to apply ICC color correction to image.
  *
- * Copyright 2005-2006 by F.J. Cruz and Gilles Caulier
+ * Copyright (C) 2005-2006 by F.J. Cruz <fj.cruz@supercable.es>
+ * Copyright (C) 2005-2007 by Gilles Caulier <caulier dot gilles at gmail dot com> 
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -235,7 +238,7 @@ bool IccTransform::apply(DImg& image)
     cmsHPROFILE   inprofile=0, outprofile=0, proofprofile=0;
     cmsHTRANSFORM transform;
     int inputFormat = 0;
-    int intent;
+    int intent      = INTENT_PERCEPTUAL;
 
     switch (getRenderingIntent())
     {
