@@ -5,9 +5,9 @@
  *
  * Date        : 2005-06-17
  * Description : A TIFF IO file for DImg framework
- * 
+ *
  * Copyright (C) 2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com> 
+ * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com> 
  *
  * Specifications & references:
  * - TIFF 6.0  : http://partners.adobe.com/public/developer/en/tiff/TIFF6.pdf
@@ -31,12 +31,12 @@
  * Public License as published by the Free Software Foundation;
  * either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * ============================================================ */
 
 // This line must be commented to prevent any latency time
@@ -75,7 +75,7 @@ namespace Digikam
 
 void TIFFLoader::dimg_tiff_warning(const char* module, const char* format, va_list warnings)
 {
-#ifdef ENABLE_DEBUG_MESSAGES    
+#ifdef ENABLE_DEBUG_MESSAGES
     char message[4096];
     vsnprintf(message, 4096, format, warnings);
     DDebug() << module <<  "::" <<  message << endl;
@@ -88,7 +88,7 @@ void TIFFLoader::dimg_tiff_warning(const char* module, const char* format, va_li
 
 void TIFFLoader::dimg_tiff_error(const char* module, const char* format, va_list errors)
 {
-#ifdef ENABLE_DEBUG_MESSAGES    
+#ifdef ENABLE_DEBUG_MESSAGES
     char message[4096];
     vsnprintf(message, 4096, format, errors);
     DDebug() << module << "::" << message << endl;
@@ -119,7 +119,7 @@ bool TIFFLoader::load(const QString& filePath, DImgLoaderObserver *observer)
 
     // -------------------------------------------------------------------
     // Open the file
-    
+
     TIFF* tif = TIFFOpen(QFile::encodeName(filePath), "r");
     if (!tif)
     {
@@ -127,13 +127,13 @@ bool TIFFLoader::load(const QString& filePath, DImgLoaderObserver *observer)
         return false;
     }
 
-#ifdef ENABLE_DEBUG_MESSAGES    
+#ifdef ENABLE_DEBUG_MESSAGES
     TIFFPrintDirectory(tif, stdout, 0);
 #endif
-    
+
     // -------------------------------------------------------------------
     // Get image information.
-    
+
     uint32    w, h;
     uint16    bits_per_sample;
     uint16    samples_per_pixel;
@@ -195,12 +195,12 @@ bool TIFFLoader::load(const QString& filePath, DImgLoaderObserver *observer)
 
     // -------------------------------------------------------------------
     // Read image ICC profile
-    
+
     QMap<int, QByteArray>& metaData = imageMetaData();
 
     uchar  *profile_data=NULL;
     uint32  profile_size;
-    
+
     if (TIFFGetField (tif, TIFFTAG_ICCPROFILE, &profile_size, &profile_data))
     {
         QByteArray profile_rawdata(profile_size);
@@ -218,9 +218,9 @@ bool TIFFLoader::load(const QString& filePath, DImgLoaderObserver *observer)
 
     if (observer)
         observer->progressInfo(m_image, 0.1);
-    
+
     uchar* data   = 0;
-    
+
     strip_size    = TIFFStripSize(tif);
     num_of_strips = TIFFNumberOfStrips(tif);
 
@@ -262,7 +262,7 @@ bool TIFFLoader::load(const QString& filePath, DImgLoaderObserver *observer)
             ushort *dataPtr  = (ushort*)(data + offset);
             ushort *p;
 
-            // tiff data is read as BGR or ABGR
+            // tiff data is read as BGR or ABGR or Greyscale
 
             if (samples_per_pixel == 3)
             {
@@ -291,7 +291,34 @@ bool TIFFLoader::load(const QString& filePath, DImgLoaderObserver *observer)
 
                 offset += bytesRead/6 * 8;
             }
-            else
+            else if (samples_per_pixel == 1)   // See B.K.O #148400: Greyscale pictures only have _one_ sample per pixel
+            {
+                for (int i=0; i < bytesRead/2; i++)
+                {
+                    // We have to read two bytes for one pixel
+                    p = dataPtr;
+
+                    // See B.K.O #148037 : take a care about byte order with Motorola computers.
+                    if (QImage::systemByteOrder() == QImage::BigEndian)     // PPC
+                    {
+                        p[3] = 0xFFFF;
+                        p[0] = *stripPtr;
+                        p[1] = *stripPtr;
+                        p[2] = *stripPtr++;
+                    }
+                    else
+                    {
+                        p[0] = *stripPtr;      // RGB have to be set to the _same_ value
+                        p[1] = *stripPtr;
+                        p[2] = *stripPtr++;
+                        p[3] = 0xFFFF;         // set alpha to 100%
+                    }
+                    dataPtr += 4;
+                }
+
+                offset += bytesRead*4;         // The _byte_offset in the data array is, of course, four times bytesRead
+            }
+            else // ABGR
             {
                 for (int i=0; i < bytesRead/8; i++)
                 {
@@ -396,7 +423,7 @@ bool TIFFLoader::load(const QString& filePath, DImgLoaderObserver *observer)
             for (int i=0; i < pixelsRead; i++)
             {
                 p = dataPtr;
-                
+
                 // See B.K.O #148037 : take a care about byte order with Motorola computers.
                 if (QImage::systemByteOrder() == QImage::BigEndian)     // PPC
                 {
@@ -424,7 +451,7 @@ bool TIFFLoader::load(const QString& filePath, DImgLoaderObserver *observer)
     }
 
     // -------------------------------------------------------------------
-    
+
     TIFFClose(tif);
 
     if (observer)
@@ -434,7 +461,7 @@ bool TIFFLoader::load(const QString& filePath, DImgLoaderObserver *observer)
     imageHeight() = h;
     imageData()   = data;
     imageSetAttribute("format", "TIFF");
-    
+
     return true;
 }
 
@@ -443,11 +470,11 @@ bool TIFFLoader::save(const QString& filePath, DImgLoaderObserver *observer)
     TIFF   *tif;
     uchar  *data;
     uint32  w, h;
-    
+
     w    = imageWidth();
     h    = imageHeight();
     data = imageData();
-    
+
     // -------------------------------------------------------------------
     // TIFF error handling. If an errors/warnings occurs during reading, 
     // libtiff will call these methods
@@ -457,9 +484,9 @@ bool TIFFLoader::save(const QString& filePath, DImgLoaderObserver *observer)
 
     // -------------------------------------------------------------------
     // Open the file
-    
+
     tif = TIFFOpen(QFile::encodeName(filePath), "w");
-        
+
     if (!tif)
     {
         DDebug() << k_funcinfo << "Cannot open target image file." << endl;
@@ -468,18 +495,18 @@ bool TIFFLoader::save(const QString& filePath, DImgLoaderObserver *observer)
 
     // -------------------------------------------------------------------
     // Set image properties
-    
+
     TIFFSetField(tif, TIFFTAG_IMAGEWIDTH,     w);
     TIFFSetField(tif, TIFFTAG_IMAGELENGTH,    h);
     TIFFSetField(tif, TIFFTAG_PHOTOMETRIC,    PHOTOMETRIC_RGB);
     TIFFSetField(tif, TIFFTAG_PLANARCONFIG,   PLANARCONFIG_CONTIG);
     TIFFSetField(tif, TIFFTAG_ORIENTATION,    ORIENTATION_TOPLEFT);
     TIFFSetField(tif, TIFFTAG_RESOLUTIONUNIT, RESUNIT_NONE);
- 
+
     // Image must be compressed using deflate algorithm ?
     QVariant compressAttr = imageGetAttribute("compress");
     bool compress = compressAttr.isValid() ? compressAttr.toBool() : false;
-    
+
     if (compress)
     {
         TIFFSetField(tif, TIFFTAG_COMPRESSION, COMPRESSION_ADOBE_DEFLATE);
@@ -498,8 +525,9 @@ bool TIFFLoader::save(const QString& filePath, DImgLoaderObserver *observer)
     // Image has an alpha channel ?
     if (imageHasAlpha())
     {
+        uint16 sampleinfo[1] = { EXTRASAMPLE_UNASSALPHA };
         TIFFSetField(tif, TIFFTAG_SAMPLESPERPIXEL, 4);
-        TIFFSetField(tif, TIFFTAG_EXTRASAMPLES,    EXTRASAMPLE_ASSOCALPHA);
+        TIFFSetField(tif, TIFFTAG_EXTRASAMPLES,    EXTRASAMPLE_ASSOCALPHA, sampleinfo);
     }
     else
     {
@@ -511,13 +539,12 @@ bool TIFFLoader::save(const QString& filePath, DImgLoaderObserver *observer)
 
     // -------------------------------------------------------------------
     // Write meta-data Tags contents. 
-    // TODO : - this code will be removed when Exiv2 will support TIFF in writing mode
-        
+
     DMetadata metaData;
     metaData.setExif(m_image->getExif());
     metaData.setIptc(m_image->getIptc());
 
-    // Standard IPTC tag (available with libtiff 3.6.1)    
+    // Standard IPTC tag (available with libtiff 3.6.1)
 
     QByteArray ba = metaData.getIptc(true);
     if (!ba.isEmpty()) 
@@ -527,13 +554,13 @@ bool TIFFLoader::save(const QString& filePath, DImgLoaderObserver *observer)
 #endif
     }
 
-    // Standard XMP tag (available with libtiff 3.6.1)    
+    // Standard XMP tag (available with libtiff 3.6.1)
 
 #if defined(TIFFTAG_XMLPACKET)
     tiffSetExifDataTag(tif, TIFFTAG_XMLPACKET,                &metaData, "Exif.Image.XMLPacket");
 #endif
 
-    // Standard Exif Ascii tags (available with libtiff 3.6.1)    
+    // Standard Exif Ascii tags (available with libtiff 3.6.1)
 
     tiffSetExifAsciiTag(tif, TIFFTAG_DOCUMENTNAME,            &metaData, "Exif.Image.DocumentName");
     tiffSetExifAsciiTag(tif, TIFFTAG_IMAGEDESCRIPTION,        &metaData, "Exif.Image.ImageDescription");
@@ -549,205 +576,26 @@ bool TIFFLoader::save(const QString& filePath, DImgLoaderObserver *observer)
     soft.append(QString(" ( %1 )").arg(libtiffver));
     TIFFSetField(tif, TIFFTAG_SOFTWARE, (const char*)soft.ascii());
 
-    // Standard Exif.Photo tags (available with libtiff 3.8.2).  
-/*
-#if defined(TIFFTAG_EXIFIFD)
-    long sub_offset=0;
-    TIFFSetField(tif, TIFFTAG_SUBIFD, 1, &sub_offset);
-#endif  
+    // NOTE: All others Exif tags will be written by Exiv2 (<= 0.18)
 
-#if defined(EXIFTAG_EXPOSURETIME)
-    tiffSetExifDataTag(tif, EXIFTAG_EXPOSURETIME,             &metaData, "Exif.Photo.ExposureTime");
-#endif  
-#if defined(EXIFTAG_FNUMBER)
-    tiffSetExifDataTag(tif, EXIFTAG_FNUMBER,                  &metaData, "Exif.Photo.FNumber");
-#endif  
-#if defined(EXIFTAG_EXPOSUREPROGRAM)
-    tiffSetExifDataTag(tif, EXIFTAG_EXPOSUREPROGRAM,          &metaData, "Exif.Photo.ExposureProgram");
-#endif  
-#if defined(EXIFTAG_SPECTRALSENSITIVITY)
-    tiffSetExifAsciiTag(tif, EXIFTAG_SPECTRALSENSITIVITY,     &metaData, "Exif.Photo.SpectralSensitivity");
-#endif
-#if defined(EXIFTAG_ISOSPEEDRATINGS)
-    tiffSetExifDataTag(tif, EXIFTAG_ISOSPEEDRATINGS,          &metaData, "Exif.Photo.ISOSpeedRatings");
-#endif  
-#if defined(EXIFTAG_OECF)
-    tiffSetExifDataTag(tif, EXIFTAG_OECF,                     &metaData, "Exif.Photo.OECF");
-#endif  
-#if defined(EXIFTAG_EXIFVERSION)
-    tiffSetExifDataTag(tif, EXIFTAG_EXIFVERSION,              &metaData, "Exif.Photo.ExifVersion");
-#endif  
-#if defined(EXIFTAG_DATETIMEORIGINAL)
-    tiffSetExifAsciiTag(tif, EXIFTAG_DATETIMEORIGINAL,        &metaData, "Exif.Photo.DateTimeOriginal");
-#endif
-#if defined(EXIFTAG_DATETIMEDIGITIZED)
-    tiffSetExifAsciiTag(tif, EXIFTAG_DATETIMEDIGITIZED,       &metaData, "Exif.Photo.DateTimeDigitized");
-#endif
-#if defined(EXIFTAG_COMPONENTSCONFIGURATION)
-    tiffSetExifDataTag(tif, EXIFTAG_COMPONENTSCONFIGURATION,  &metaData, "Exif.Photo.ComponentsConfiguration");
-#endif  
-#if defined(EXIFTAG_COMPRESSEDBITSPERPIXEL)
-    tiffSetExifDataTag(tif, EXIFTAG_COMPRESSEDBITSPERPIXEL,   &metaData, "Exif.Photo.CompressedBitsPerPixel");
-#endif  
-#if defined(EXIFTAG_SHUTTERSPEEDVALUE)
-    tiffSetExifDataTag(tif, EXIFTAG_SHUTTERSPEEDVALUE,        &metaData, "Exif.Photo.ShutterSpeedValue");
-#endif  
-#if defined(EXIFTAG_APERTUREVALUE)
-    tiffSetExifDataTag(tif, EXIFTAG_APERTUREVALUE,            &metaData, "Exif.Photo.ApertureValue");
-#endif
-#if defined(EXIFTAG_BRIGHTNESSVALUE)
-    tiffSetExifDataTag(tif, EXIFTAG_BRIGHTNESSVALUE,          &metaData, "Exif.Photo.BrightnessValue");
-#endif
-#if defined(EXIFTAG_EXPOSUREBIASVALUE)
-    tiffSetExifDataTag(tif, EXIFTAG_EXPOSUREBIASVALUE,        &metaData, "Exif.Photo.ExposureBiasValue");
-#endif
-#if defined(EXIFTAG_MAXAPERTUREVALUE)
-    tiffSetExifDataTag(tif, EXIFTAG_MAXAPERTUREVALUE,         &metaData, "Exif.Photo.MaxApertureValue");
-#endif
-#if defined(EXIFTAG_SUBJECTDISTANCE)
-    tiffSetExifDataTag(tif, EXIFTAG_SUBJECTDISTANCE,          &metaData, "Exif.Photo.SubjectDistance");
-#endif
-#if defined(EXIFTAG_METERINGMODE)
-    tiffSetExifDataTag(tif, EXIFTAG_METERINGMODE,             &metaData, "Exif.Photo.MeteringMode");
-#endif
-#if defined(EXIFTAG_LIGHTSOURCE)
-    tiffSetExifDataTag(tif, EXIFTAG_LIGHTSOURCE,              &metaData, "Exif.Photo.LightSource");
-#endif
-#if defined(EXIFTAG_FLASH)
-    tiffSetExifDataTag(tif, EXIFTAG_FLASH,                    &metaData, "Exif.Photo.Flash");
-#endif
-#if defined(EXIFTAG_FOCALLENGTH)
-    tiffSetExifDataTag(tif, EXIFTAG_FOCALLENGTH,              &metaData, "Exif.Photo.FocalLength");
-#endif
-#if defined(EXIFTAG_SUBJECTAREA)
-    tiffSetExifDataTag(tif, EXIFTAG_SUBJECTAREA,              &metaData, "Exif.Photo.SubjectArea");
-#endif
-#if defined(EXIFTAG_MAKERNOTE)
-    tiffSetExifDataTag(tif, EXIFTAG_MAKERNOTE,                &metaData, "Exif.Photo.MakerNote");
-#endif
-#if defined(EXIFTAG_USERCOMMENT)   
-    tiffSetExifDataTag(tif, EXIFTAG_USERCOMMENT,              &metaData, "Exif.Photo.UserComment");
-#endif
-#if defined(EXIFTAG_SUBSECTIME)
-    tiffSetExifAsciiTag(tif, EXIFTAG_SUBSECTIME,              &metaData, "Exif.Photo.SubSecTime");
-#endif
-#if defined(EXIFTAG_SUBSECTIMEORIGINAL)
-    tiffSetExifAsciiTag(tif, EXIFTAG_SUBSECTIMEORIGINAL,      &metaData, "Exif.Photo.SubSecTimeOriginal");
-#endif
-#if defined(EXIFTAG_SUBSECTIMEDIGITIZED)
-    tiffSetExifAsciiTag(tif, EXIFTAG_SUBSECTIMEDIGITIZED,     &metaData, "Exif.Photo.SubSecTimeDigitized");
-#endif
-#if defined(EXIFTAG_FLASHPIXVERSION)
-    tiffSetExifDataTag(tif, EXIFTAG_FLASHPIXVERSION,          &metaData, "Exif.Photo.FlashpixVersion");
-#endif
-#if defined(EXIFTAG_COLORSPACE)
-    tiffSetExifDataTag(tif, EXIFTAG_COLORSPACE,               &metaData, "Exif.Photo.ColorSpace");
-#endif
-#if defined(EXIFTAG_PIXELXDIMENSION)
-    tiffSetExifDataTag(tif, EXIFTAG_PIXELXDIMENSION,          &metaData, "Exif.Photo.PixelXDimension");
-#endif
-#if defined(EXIFTAG_PIXELYDIMENSION)
-    tiffSetExifDataTag(tif, EXIFTAG_PIXELYDIMENSION,          &metaData, "Exif.Photo.PixelYDimension");
-#endif
-#if defined(EXIFTAG_RELATEDSOUNDFILE)
-    tiffSetExifAsciiTag(tif, EXIFTAG_RELATEDSOUNDFILE,        &metaData, "Exif.Photo.RelatedSoundFile");
-#endif
-#if defined(EXIFTAG_FLASHENERGY)
-    tiffSetExifDataTag(tif, EXIFTAG_FLASHENERGY,              &metaData, "Exif.Photo.FlashEnergy");
-#endif
-#if defined(EXIFTAG_SPATIALFREQUENCYRESPONSE)
-    tiffSetExifDataTag(tif, EXIFTAG_SPATIALFREQUENCYRESPONSE, &metaData, "Exif.Photo.SpatialFrequencyResponse");
-#endif
-#if defined(EXIFTAG_FOCALPLANEXRESOLUTION)
-    tiffSetExifDataTag(tif, EXIFTAG_FOCALPLANEXRESOLUTION,    &metaData, "Exif.Photo.FocalPlaneXResolution");
-#endif
-#if defined(EXIFTAG_FOCALPLANEYRESOLUTION)
-    tiffSetExifDataTag(tif, EXIFTAG_FOCALPLANEYRESOLUTION,    &metaData, "Exif.Photo.FocalPlaneYResolution");
-#endif
-#if defined(EXIFTAG_FOCALPLANERESOLUTIONUNIT)
-    tiffSetExifDataTag(tif, EXIFTAG_FOCALPLANERESOLUTIONUNIT, &metaData, "Exif.Photo.FocalPlaneResolutionUnit");
-#endif
-#if defined(EXIFTAG_SUBJECTLOCATION)
-    tiffSetExifDataTag(tif, EXIFTAG_SUBJECTLOCATION,          &metaData, "Exif.Photo.SubjectLocation");
-#endif
-#if defined(EXIFTAG_EXPOSUREINDEX)
-    tiffSetExifDataTag(tif, EXIFTAG_EXPOSUREINDEX,            &metaData, "Exif.Photo.ExposureIndex");
-#endif
-#if defined(EXIFTAG_SENSINGMETHOD)
-    tiffSetExifDataTag(tif, EXIFTAG_SENSINGMETHOD,            &metaData, "Exif.Photo.SensingMethod");
-#endif
-#if defined(EXIFTAG_FILESOURCE)
-    tiffSetExifDataTag(tif, EXIFTAG_FILESOURCE,               &metaData, "Exif.Photo.FileSource");
-#endif
-#if defined(EXIFTAG_SCENETYPE)
-    tiffSetExifDataTag(tif, EXIFTAG_SCENETYPE,                &metaData, "Exif.Photo.SceneType");
-#endif
-#if defined(EXIFTAG_CFAPATTERN)
-    tiffSetExifDataTag(tif, EXIFTAG_CFAPATTERN,               &metaData, "Exif.Photo.CFAPattern");
-#endif
-#if defined(EXIFTAG_CUSTOMRENDERED)
-    tiffSetExifDataTag(tif, EXIFTAG_CUSTOMRENDERED,           &metaData, "Exif.Photo.CustomRendered");
-#endif
-#if defined(EXIFTAG_EXPOSUREMODE)
-    tiffSetExifDataTag(tif, EXIFTAG_EXPOSUREMODE,             &metaData, "Exif.Photo.ExposureMode");
-#endif
-#if defined(EXIFTAG_WHITEBALANCE)
-    tiffSetExifDataTag(tif, EXIFTAG_WHITEBALANCE,             &metaData, "Exif.Photo.WhiteBalance");
-#endif
-#if defined(EXIFTAG_DIGITALZOOMRATIO)
-    tiffSetExifDataTag(tif, EXIFTAG_DIGITALZOOMRATIO,         &metaData, "Exif.Photo.DigitalZoomRatio");
-#endif
-#if defined(EXIFTAG_FOCALLENGTHIN35MMFILM)
-    tiffSetExifDataTag(tif, EXIFTAG_FOCALLENGTHIN35MMFILM,    &metaData, "Exif.Photo.FocalLengthIn35mmFilm");
-#endif
-#if defined(EXIFTAG_SCENECAPTURETYPE)
-    tiffSetExifDataTag(tif, EXIFTAG_SCENECAPTURETYPE,         &metaData, "Exif.Photo.SceneCaptureType");
-#endif
-#if defined(EXIFTAG_GAINCONTROL)
-    tiffSetExifDataTag(tif, EXIFTAG_GAINCONTROL,              &metaData, "Exif.Photo.GainControl");
-#endif
-#if defined(EXIFTAG_CONTRAST)
-    tiffSetExifDataTag(tif, EXIFTAG_CONTRAST,                 &metaData, "Exif.Photo.Contrast");
-#endif
-#if defined(EXIFTAG_SATURATION)
-    tiffSetExifDataTag(tif, EXIFTAG_SATURATION,               &metaData, "Exif.Photo.Saturation");
-#endif
-#if defined(EXIFTAG_SHARPNESS)
-    tiffSetExifDataTag(tif, EXIFTAG_SHARPNESS,                &metaData, "Exif.Photo.Sharpness");
-#endif 
-#if defined(EXIFTAG_DEVICESETTINGDESCRIPTION)
-    tiffSetExifDataTag(tif, EXIFTAG_DEVICESETTINGDESCRIPTION, &metaData, "Exif.Photo.DeviceSettingDescription");
-#endif 
-#if defined(EXIFTAG_SUBJECTDISTANCERANGE)
-    tiffSetExifDataTag(tif, EXIFTAG_SUBJECTDISTANCERANGE,     &metaData, "Exif.Photo.SubjectDistanceRange");
-#endif 
-#if defined(EXIFTAG_IMAGEUNIQUEID)
-    tiffSetExifAsciiTag(tif, EXIFTAG_IMAGEUNIQUEID,           &metaData, "Exif.Photo.ImageUniqueID");
-#endif
-
-#if defined(TIFFTAG_EXIFIFD)
-    TIFFSetField(tif, TIFFTAG_EXIFIFD, sub_offset);
-#endif
-*/
-    
     // -------------------------------------------------------------------
     // Write ICC profil.
-    
+
     QByteArray profile_rawdata = m_image->getICCProfil();
-    
+
     if (!profile_rawdata.isEmpty())
     {
-#if defined(TIFFTAG_ICCPROFILE)    
+#if defined(TIFFTAG_ICCPROFILE)
         TIFFSetField(tif, TIFFTAG_ICCPROFILE, (uint32)profile_rawdata.size(), (uchar *)profile_rawdata.data());
-#endif      
-    }    
+#endif
+    }
 
     // -------------------------------------------------------------------
     // Write full image data in tiff directory IFD0
 
     if (observer)
         observer->progressInfo(m_image, 0.1);
-    
+
     uint8  *buf=0;
     uchar  *pixel;
     double  alpha_factor;
@@ -783,37 +631,37 @@ bool TIFFLoader::save(const QString& filePath, DImgLoaderObserver *observer)
         }
 
         i = 0;
-        
+
         for (x = 0; x < w; x++)
         {
             pixel = &data[((y * w) + x) * imageBytesDepth()];
-            
+
             if ( imageSixteenBit() )        // 16 bits image.
             {
                 b16 = (uint16)(pixel[0]+256*pixel[1]);
                 g16 = (uint16)(pixel[2]+256*pixel[3]);
                 r16 = (uint16)(pixel[4]+256*pixel[5]);
-                
+
                 if (imageHasAlpha())
                 {
                     // TIFF makes you pre-mutiply the rgb components by alpha 
-                    
+
                     a16          = (uint16)(pixel[6]+256*pixel[7]);
                     alpha_factor = ((double)a16 / 65535.0);
                     r16          = (uint16)(r16*alpha_factor);
                     g16          = (uint16)(g16*alpha_factor);
                     b16          = (uint16)(b16*alpha_factor);
                 }
-    
+
                 // This might be endian dependent 
-                
+
                 buf[i++] = (uint8)(r16);
                 buf[i++] = (uint8)(r16 >> 8);
                 buf[i++] = (uint8)(g16);
                 buf[i++] = (uint8)(g16 >> 8);
                 buf[i++] = (uint8)(b16);
                 buf[i++] = (uint8)(b16 >> 8);
-                
+
                 if (imageHasAlpha())
                 {
                     buf[i++] = (uint8)(a16) ;
@@ -825,24 +673,24 @@ bool TIFFLoader::save(const QString& filePath, DImgLoaderObserver *observer)
                 b8 = (uint8)pixel[0];
                 g8 = (uint8)pixel[1];
                 r8 = (uint8)pixel[2];
-                
+
                 if (imageHasAlpha())
                 {
                     // TIFF makes you pre-mutiply the rgb components by alpha 
-                    
+
                     a8           = (uint8)(pixel[3]);
                     alpha_factor = ((double)a8 / 255.0);
                     r8           = (uint8)(r8*alpha_factor);
                     g8           = (uint8)(g8*alpha_factor);
                     b8           = (uint8)(b8*alpha_factor);
                 }
-    
+
                 // This might be endian dependent 
-                
+
                 buf[i++] = r8;
                 buf[i++] = g8;
                 buf[i++] = b8;
-                
+
                 if (imageHasAlpha())
                     buf[i++] = a8;
             }
@@ -890,11 +738,11 @@ bool TIFFLoader::save(const QString& filePath, DImgLoaderObserver *observer)
     for (y = 0 ; y < uint32(thumb.height()) ; y++)
     {
         i = 0;
-        
+
         for (x = 0 ; x < uint32(thumb.width()) ; x++)
         {
             pixelThumb = &dataThumb[((y * thumb.width()) + x) * 4];
-            
+
             // This might be endian dependent 
             bufThumb[i++] = (uint8)pixelThumb[2];
             bufThumb[i++] = (uint8)pixelThumb[1];
@@ -919,25 +767,24 @@ bool TIFFLoader::save(const QString& filePath, DImgLoaderObserver *observer)
         observer->progressInfo(m_image, 1.0);
 
     imageSetAttribute("savedformat", "TIFF");
-        
-    // TODO : enable this line when Exiv2 will support TIFF in writing mode.
-    //saveMetadata(filePath);
-    
+
+    saveMetadata(filePath);
+
     return true;
 }
 
 bool TIFFLoader::hasAlpha() const
 {
-    return m_hasAlpha;    
+    return m_hasAlpha;
 }
 
 bool TIFFLoader::sixteenBit() const
 {
-    return m_sixteenBit;    
+    return m_sixteenBit;
 }
 
-void TIFFLoader::tiffSetExifAsciiTag(TIFF* tif, ttag_t tiffTag, 
-                                     DMetadata *metaData, const char* exifTagName)
+void TIFFLoader::tiffSetExifAsciiTag(TIFF* tif, ttag_t tiffTag,
+                                     const DMetadata *metaData, const char* exifTagName)
 {
     QByteArray tag = metaData->getExifTagData(exifTagName);
     if (!tag.isEmpty()) 
@@ -947,8 +794,8 @@ void TIFFLoader::tiffSetExifAsciiTag(TIFF* tif, ttag_t tiffTag,
     }
 }
 
-void TIFFLoader::tiffSetExifDataTag(TIFF* tif, ttag_t tiffTag, 
-                                    DMetadata *metaData, const char* exifTagName)
+void TIFFLoader::tiffSetExifDataTag(TIFF* tif, ttag_t tiffTag,
+                                    const DMetadata *metaData, const char* exifTagName)
 {
     QByteArray tag = metaData->getExifTagData(exifTagName);
     if (!tag.isEmpty()) 
