@@ -6,7 +6,7 @@
  * Date        : 2006-04-19
  * Description : A tab to display general image information
  *
- * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -42,7 +42,7 @@
 
 // LibKDcraw includes.
 
-#include <libkdcraw/rawfiles.h>
+#include <libkdcraw/dcrawbinary.h>
 
 // Local includes.
 
@@ -424,7 +424,7 @@ void ImagePropertiesTab::setCurrentURL(const KURL& url)
 
     QSize   dims;
     QString compression, bitDepth, colorMode;
-    QString rawFilesExt(raw_file_extentions);
+    QString rawFilesExt(KDcrawIface::DcrawBinary::instance()->rawFiles());
     QString ext = fileInfo.extension(false).upper();
 
     if (!ext.isEmpty() && rawFilesExt.upper().contains(ext))
@@ -582,112 +582,4 @@ void ImagePropertiesTab::setCurrentURL(const KURL& url)
     d->labelPhotoWhiteBalance->setText(photoInfo.whiteBalance.isEmpty() ? unavailable : photoInfo.whiteBalance);
 }
 
-void ImagePropertiesTab::colorChanged(const QColor& back, const QColor& fore)
-{
-    d->settingsArea->setPaletteBackgroundColor(back);
-
-    d->title->setPaletteBackgroundColor(back);
-    d->file->setPaletteBackgroundColor(back);
-    d->folder->setPaletteBackgroundColor(back);
-    d->modifiedDate->setPaletteBackgroundColor(back);
-    d->size->setPaletteBackgroundColor(back);
-    d->owner->setPaletteBackgroundColor(back);
-    d->permissions->setPaletteBackgroundColor(back);
-
-    d->title2->setPaletteBackgroundColor(back);
-    d->mime->setPaletteBackgroundColor(back);
-    d->dimensions->setPaletteBackgroundColor(back);
-    d->compression->setPaletteBackgroundColor(back);
-    d->bitDepth->setPaletteBackgroundColor(back);
-    d->colorMode->setPaletteBackgroundColor(back);
-
-    d->title3->setPaletteBackgroundColor(back);
-    d->make->setPaletteBackgroundColor(back);
-    d->model->setPaletteBackgroundColor(back);
-    d->photoDate->setPaletteBackgroundColor(back);
-    d->aperture->setPaletteBackgroundColor(back);
-    d->focalLength->setPaletteBackgroundColor(back);
-    d->exposureTime->setPaletteBackgroundColor(back);
-    d->sensitivity->setPaletteBackgroundColor(back);
-    d->exposureMode->setPaletteBackgroundColor(back);
-    d->flash->setPaletteBackgroundColor(back);
-    d->whiteBalance->setPaletteBackgroundColor(back);
-
-    d->labelFile->setPaletteBackgroundColor(back);
-    d->labelFolder->setPaletteBackgroundColor(back);
-    d->labelFileModifiedDate->setPaletteBackgroundColor(back);
-    d->labelFileSize->setPaletteBackgroundColor(back);
-    d->labelFileOwner->setPaletteBackgroundColor(back);
-    d->labelFilePermissions->setPaletteBackgroundColor(back);
-
-    d->labelImageMime->setPaletteBackgroundColor(back);
-    d->labelImageDimensions->setPaletteBackgroundColor(back);
-    d->labelImageCompression->setPaletteBackgroundColor(back);
-    d->labelImageBitDepth->setPaletteBackgroundColor(back);
-    d->labelImageColorMode->setPaletteBackgroundColor(back);
-
-    d->labelPhotoMake->setPaletteBackgroundColor(back);
-    d->labelPhotoModel->setPaletteBackgroundColor(back);
-    d->labelPhotoDateTime->setPaletteBackgroundColor(back);
-    d->labelPhotoAperture->setPaletteBackgroundColor(back);
-    d->labelPhotoFocalLenght->setPaletteBackgroundColor(back);
-    d->labelPhotoExposureTime->setPaletteBackgroundColor(back);
-    d->labelPhotoSensitivity->setPaletteBackgroundColor(back);
-    d->labelPhotoExposureMode->setPaletteBackgroundColor(back);
-    d->labelPhotoFlash->setPaletteBackgroundColor(back);
-    d->labelPhotoWhiteBalance->setPaletteBackgroundColor(back);
-
-    d->title->setPaletteForegroundColor(fore);
-    d->file->setPaletteForegroundColor(fore);
-    d->folder->setPaletteForegroundColor(fore);
-    d->modifiedDate->setPaletteForegroundColor(fore);
-    d->size->setPaletteForegroundColor(fore);
-    d->owner->setPaletteForegroundColor(fore);
-    d->permissions->setPaletteForegroundColor(fore);
-
-    d->title2->setPaletteForegroundColor(fore);
-    d->mime->setPaletteForegroundColor(fore);
-    d->dimensions->setPaletteForegroundColor(fore);
-    d->compression->setPaletteForegroundColor(fore);
-    d->bitDepth->setPaletteForegroundColor(fore);
-    d->colorMode->setPaletteForegroundColor(fore);
-
-    d->title3->setPaletteForegroundColor(fore);
-    d->make->setPaletteForegroundColor(fore);
-    d->model->setPaletteForegroundColor(fore);
-    d->photoDate->setPaletteForegroundColor(fore);
-    d->aperture->setPaletteForegroundColor(fore);
-    d->focalLength->setPaletteForegroundColor(fore);
-    d->exposureTime->setPaletteForegroundColor(fore);
-    d->sensitivity->setPaletteForegroundColor(fore);
-    d->exposureMode->setPaletteForegroundColor(fore);
-    d->flash->setPaletteForegroundColor(fore);
-    d->whiteBalance->setPaletteForegroundColor(fore);
-
-    d->labelFile->setPaletteForegroundColor(fore);
-    d->labelFolder->setPaletteForegroundColor(fore);
-    d->labelFileModifiedDate->setPaletteForegroundColor(fore);
-    d->labelFileSize->setPaletteForegroundColor(fore);
-    d->labelFileOwner->setPaletteForegroundColor(fore);
-    d->labelFilePermissions->setPaletteForegroundColor(fore);
-
-    d->labelImageMime->setPaletteForegroundColor(fore);
-    d->labelImageDimensions->setPaletteForegroundColor(fore);
-    d->labelImageCompression->setPaletteForegroundColor(fore);
-    d->labelImageBitDepth->setPaletteForegroundColor(fore);
-    d->labelImageColorMode->setPaletteForegroundColor(fore);
-
-    d->labelPhotoMake->setPaletteForegroundColor(fore);
-    d->labelPhotoModel->setPaletteForegroundColor(fore);
-    d->labelPhotoDateTime->setPaletteForegroundColor(fore);
-    d->labelPhotoAperture->setPaletteForegroundColor(fore);
-    d->labelPhotoFocalLenght->setPaletteForegroundColor(fore);
-    d->labelPhotoExposureTime->setPaletteForegroundColor(fore);
-    d->labelPhotoSensitivity->setPaletteForegroundColor(fore);
-    d->labelPhotoExposureMode->setPaletteForegroundColor(fore);
-    d->labelPhotoFlash->setPaletteForegroundColor(fore);
-    d->labelPhotoWhiteBalance->setPaletteForegroundColor(fore);
-}
-
 }  // NameSpace Digikam
-
