@@ -7,7 +7,7 @@
  * Description : a bar widget to display image thumbnails
  * 
  * Copyright (C) 2004-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Copyright (C) 2005-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * 
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -52,15 +52,14 @@ extern "C"
 #include <kfileitem.h>
 #include <kapplication.h>
 #include <kiconloader.h>
-#include <kio/previewjob.h>
 #include <klocale.h>
 #include <kmimetype.h>
 #include <kfileitem.h>
 #include <kglobal.h>
 
-// LibKDcraw includes. 
- 
-#include <libkdcraw/rawfiles.h> 
+// LibKDcraw includes.
+
+#include <libkdcraw/dcrawbinary.h>
 
 // Local includes.
 
@@ -82,7 +81,7 @@ public:
     {
         dragging   = false;
         exifRotate = false;
-	clearing   = false;
+        clearing   = false;
         toolTip    = 0;
         firstItem  = 0;
         lastItem   = 0;
@@ -93,7 +92,7 @@ public:
 
         itemDict.setAutoDelete(false);
     }
-    
+
     bool                       clearing;
     bool                       exifRotate;
     bool                       dragging;
@@ -102,7 +101,7 @@ public:
     int                        count;
     int                        tileSize;
     int                        orientation;
-    
+
     QTimer                    *timer;
 
     QPoint                     dragStartPos;
@@ -133,16 +132,16 @@ public:
         prev   = 0;
         view   = 0;
     }
-    
+
     int           pos;
-        
+
     QPixmap      *pixmap;
 
     KURL          url;
-    
+
     ThumbBarItem *next;
     ThumbBarItem *prev;
-    
+
     ThumbBarView *view;
 };
 
@@ -158,7 +157,7 @@ ThumbBarView::ThumbBarView(QWidget* parent, int orientation, bool exifRotate,
     d->toolTipSettings = settings;
     d->toolTip         = new ThumbBarToolTip(this);
     d->timer           = new QTimer(this);
-    
+
     connect(d->timer, SIGNAL(timeout()),
             this, SLOT(slotUpdate()));
 
@@ -186,9 +185,9 @@ ThumbBarView::~ThumbBarView()
         d->thumbJob->kill();
         d->thumbJob = 0;
     }
-    
+
     clear(false);
-        
+
     delete d->timer;
     delete d->toolTip;
     delete d;
@@ -202,13 +201,15 @@ void ThumbBarView::resizeEvent(QResizeEvent* e)
 
     if (d->orientation == Vertical)
     {
-       d->tileSize = width() - 2*d->margin
-                     - verticalScrollBar()->sizeHint().width();
+        d->tileSize = width() - 2*d->margin - verticalScrollBar()->sizeHint().width();
+        verticalScrollBar()->setLineStep(d->tileSize);
+        verticalScrollBar()->setPageStep(2*d->tileSize);
     }
     else
     {
-       d->tileSize = height() - 2*d->margin
-                     - horizontalScrollBar()->sizeHint().height();
+        d->tileSize = height() - 2*d->margin - horizontalScrollBar()->sizeHint().height();
+        horizontalScrollBar()->setLineStep(d->tileSize);
+        horizontalScrollBar()->setPageStep(2*d->tileSize);
     }
 
     rearrangeItems();
@@ -227,7 +228,7 @@ void ThumbBarView::setExifRotate(bool exifRotate)
         QString uri = "file://" + QDir::cleanDirPath(item->url().path(-1));
         KMD5 md5(QFile::encodeName(uri));
         uri = md5.hexDigest();
-    
+
         QString smallThumbPath = thumbCacheDir + "normal/" + uri + ".png";
         QString bigThumbPath   = thumbCacheDir + "large/"  + uri + ".png";
 
@@ -236,7 +237,7 @@ void ThumbBarView::setExifRotate(bool exifRotate)
 
         invalidateThumb(item);
     }
-    
+
     triggerUpdate();
 }
 
@@ -303,7 +304,7 @@ void ThumbBarView::clear(bool updateView)
     d->lastItem  = 0;
     d->count     = 0;
     d->currItem  = 0;
-    
+
     if (updateView)
         slotUpdate();
 
@@ -314,17 +315,17 @@ void ThumbBarView::clear(bool updateView)
 
 void ThumbBarView::triggerUpdate()
 {
-    d->timer->start(0, true);    
+    d->timer->start(0, true);
 }
 
 ThumbBarItem* ThumbBarView::currentItem() const
 {
-    return d->currItem;    
+    return d->currItem;
 }
 
 ThumbBarItem* ThumbBarView::firstItem() const
 {
-    return d->firstItem;    
+    return d->firstItem;
 }
 
 ThumbBarItem* ThumbBarView::lastItem() const
@@ -335,12 +336,12 @@ ThumbBarItem* ThumbBarView::lastItem() const
 ThumbBarItem* ThumbBarView::findItem(const QPoint& pos) const
 {
     int itemPos;
-    
+
     if (d->orientation == Vertical)
         itemPos = pos.y();
     else
         itemPos = pos.x();
-    
+
     for (ThumbBarItem *item = d->firstItem; item; item = item->d->next)
     {
         if (itemPos >= item->d->pos && itemPos <= (item->d->pos+d->tileSize+2*d->margin))
@@ -348,7 +349,7 @@ ThumbBarItem* ThumbBarView::findItem(const QPoint& pos) const
             return item;
         }
     }
-    
+
     return 0;
 }
 
@@ -368,8 +369,8 @@ ThumbBarItem* ThumbBarView::findItemByURL(const KURL& url) const
 void ThumbBarView::setSelected(ThumbBarItem* item)
 {
     if (!item) return;
-        
-    ensureItemVisible(item);          
+
+    ensureItemVisible(item);
     emit signalURLSelected(item->url());
     emit signalItemSelected(item);
 
@@ -424,20 +425,20 @@ void ThumbBarView::invalidateThumb(ThumbBarItem* item)
         delete item->d->pixmap;
         item->d->pixmap = 0;
     }
-    
+
     if (!d->thumbJob.isNull())
     {
        d->thumbJob->kill();
        d->thumbJob = 0;
     }
-       
+
     d->thumbJob = new ThumbnailJob(item->url(), ThumbnailSize::Huge, true, d->exifRotate);
-    
+
     connect(d->thumbJob, SIGNAL(signalThumbnail(const KURL&, const QPixmap&)),
             this, SLOT(slotGotThumbnail(const KURL&, const QPixmap&)));
-   
+
     connect(d->thumbJob, SIGNAL(signalFailed(const KURL&)),
-            this, SLOT(slotFailedThumbnail(const KURL&)));     
+            this, SLOT(slotFailedThumbnail(const KURL&)));
 }
 
 void ThumbBarView::viewportPaintEvent(QPaintEvent* e)
@@ -445,34 +446,34 @@ void ThumbBarView::viewportPaintEvent(QPaintEvent* e)
     int cy, cx, ts, y1, y2, x1, x2;
     QPixmap bgPix, tile;
     QRect er(e->rect());
-    
+
     if (d->orientation == Vertical)
     {
        cy = viewportToContents(er.topLeft()).y();
-        
+
        bgPix.resize(contentsRect().width(), er.height());
-    
+
        ts = d->tileSize + 2*d->margin;
        tile.resize(visibleWidth(), ts);
-    
+
        y1 = (cy/ts)*ts;
        y2 = ((y1 + er.height())/ts +1)*ts;
     }
     else
     {
        cx = viewportToContents(er.topLeft()).x();
-        
+
        bgPix.resize(er.width(), contentsRect().height());
-    
+
        ts = d->tileSize + 2*d->margin;
        tile.resize(ts, visibleHeight());
-    
+
        x1 = (cx/ts)*ts;
        x2 = ((x1 + er.width())/ts +1)*ts;
     }
 
     bgPix.fill(colorGroup().background());
-    
+
     for (ThumbBarItem *item = d->firstItem; item; item = item->d->next)
     {
         if (d->orientation == Vertical)
@@ -483,12 +484,12 @@ void ThumbBarView::viewportPaintEvent(QPaintEvent* e)
                     tile.fill(colorGroup().highlight());
                 else
                     tile.fill(colorGroup().background());
-    
+
                 QPainter p(&tile);
                 p.setPen(Qt::white);
                 p.drawRect(0, 0, tile.width(), tile.height());
                 p.end();
-                
+
                 if (item->d->pixmap)
                 {
                     QPixmap pix; 
@@ -498,7 +499,7 @@ void ThumbBarView::viewportPaintEvent(QPaintEvent* e)
                     int y = (tile.height() - pix.height())/2;
                     bitBlt(&tile, x, y, &pix);
                 }
-                
+
                 bitBlt(&bgPix, 0, item->d->pos - cy, &tile);
             }
         }
@@ -510,12 +511,12 @@ void ThumbBarView::viewportPaintEvent(QPaintEvent* e)
                     tile.fill(colorGroup().highlight());
                 else
                     tile.fill(colorGroup().background());
-    
+
                 QPainter p(&tile);
                 p.setPen(Qt::white);
                 p.drawRect(0, 0, tile.width(), tile.height());
                 p.end();
-                
+
                 if (item->d->pixmap)
                 {
                     QPixmap pix; 
@@ -525,7 +526,7 @@ void ThumbBarView::viewportPaintEvent(QPaintEvent* e)
                     int y = (tile.height()- pix.height())/2;
                     bitBlt(&tile, x, y, &pix);
                 }
-                
+
                 bitBlt(&bgPix, item->d->pos - cx, 0, &tile);
             }
         }
@@ -572,7 +573,7 @@ void ThumbBarView::contentsMouseMoveEvent(QMouseEvent *e)
     }
 }
 
-void ThumbBarView::contentsMouseReleaseEvent(QMouseEvent* e)
+void ThumbBarView::contentsMouseReleaseEvent(QMouseEvent *e)
 {
     d->dragging = false;
     ThumbBarItem *item = findItem(e->pos());
@@ -583,6 +584,47 @@ void ThumbBarView::contentsMouseReleaseEvent(QMouseEvent* e)
     }
 }
 
+void ThumbBarView::contentsWheelEvent(QWheelEvent *e)
+{
+    e->accept();
+
+    if (e->delta() < 0)
+    {
+        if (e->state() & Qt::ShiftButton)
+        {
+            if (d->orientation == Vertical)
+                scrollBy(0, verticalScrollBar()->pageStep());
+            else
+                scrollBy(horizontalScrollBar()->pageStep(), 0);
+        }
+        else
+        {
+            if (d->orientation == Vertical)
+                scrollBy(0, verticalScrollBar()->lineStep());
+            else
+                scrollBy(horizontalScrollBar()->lineStep(), 0);
+        }
+    }
+
+    if (e->delta() > 0)
+    {
+        if (e->state() & Qt::ShiftButton)
+        {
+            if (d->orientation == Vertical)
+                scrollBy(0, (-1)*verticalScrollBar()->pageStep());
+            else
+                scrollBy((-1)*horizontalScrollBar()->pageStep(), 0);
+        }
+        else
+        {
+            if (d->orientation == Vertical)
+                scrollBy(0, (-1)*verticalScrollBar()->lineStep());
+            else
+                scrollBy((-1)*horizontalScrollBar()->lineStep(), 0);
+        }
+    }
+}
+
 void ThumbBarView::startDrag()
 {
 }
@@ -613,9 +655,9 @@ void ThumbBarView::insertItem(ThumbBarItem* item)
         emit signalURLSelected(item->url());
         emit signalItemSelected(item);
     }
-    
+
     d->itemDict.insert(item->url().url(), item);
-    
+
     d->count++;
     triggerUpdate();
     emit signalItemAdded();
@@ -660,7 +702,7 @@ void ThumbBarView::removeItem(ThumbBarItem* item)
     }
 
     d->itemDict.remove(item->url().url());
-    
+
     if (!d->clearing)
     {
         triggerUpdate();
@@ -676,7 +718,7 @@ void ThumbBarView::rearrangeItems()
 
     int pos = 0;
     ThumbBarItem *item = d->firstItem;
-    
+
     while (item)
     {
         item->d->pos = pos;
@@ -687,10 +729,10 @@ void ThumbBarView::rearrangeItems()
     }
 
     if (d->orientation == Vertical)
-       resizeContents(width(), d->count*(d->tileSize+2*d->margin));
+       resizeContents(visibleWidth(), d->count*(d->tileSize+2*d->margin));
     else    
-       resizeContents(d->count*(d->tileSize+2*d->margin), height());
-       
+       resizeContents(d->count*(d->tileSize+2*d->margin), visibleHeight());
+
     if (!urlList.isEmpty())
     {
         if (!d->thumbJob.isNull())
@@ -700,12 +742,12 @@ void ThumbBarView::rearrangeItems()
         }
 
         d->thumbJob = new ThumbnailJob(urlList, ThumbnailSize::Huge, true, d->exifRotate);
-        
+
         connect(d->thumbJob, SIGNAL(signalThumbnail(const KURL&, const QPixmap&)),
                 this, SLOT(slotGotThumbnail(const KURL&, const QPixmap&)));
-    
+
         connect(d->thumbJob, SIGNAL(signalFailed(const KURL&)),
-                this, SLOT(slotFailedThumbnail(const KURL&)));     
+                this, SLOT(slotFailedThumbnail(const KURL&)));
     }
 }
 
@@ -733,13 +775,13 @@ void ThumbBarView::slotGotThumbnail(const KURL& url, const QPixmap& pix)
         ThumbBarItem* item = d->itemDict.find(url.url());
         if (!item)
             return;
-    
+
         if (item->d->pixmap)
         {
             delete item->d->pixmap;
             item->d->pixmap = 0;
         }
-        
+
         item->d->pixmap = new QPixmap(pix);
         item->repaint();
     }
@@ -747,34 +789,7 @@ void ThumbBarView::slotGotThumbnail(const KURL& url, const QPixmap& pix)
 
 void ThumbBarView::slotFailedThumbnail(const KURL& url)
 {
-    KIO::PreviewJob* job = KIO::filePreview(url, ThumbnailSize::Huge, 0, 0, 70, true, false);
-    
-    connect(job, SIGNAL(gotPreview(const KFileItem *, const QPixmap &)),
-            this, SLOT(slotGotPreview(const KFileItem *, const QPixmap &)));
-
-    connect(job, SIGNAL(failed(const KFileItem *)),
-            this, SLOT(slotFailedPreview(const KFileItem *)));
-}
-
-void ThumbBarView::slotGotPreview(const KFileItem *fileItem, const QPixmap& pix)
-{
-    ThumbBarItem* item = d->itemDict.find(fileItem->url().url());
-    if (!item)
-        return;
-
-    if (item->d->pixmap)
-    {
-        delete item->d->pixmap;
-        item->d->pixmap = 0;
-    }
-    
-    item->d->pixmap = new QPixmap(pix);
-    item->repaint();
-}
-
-void ThumbBarView::slotFailedPreview(const KFileItem* fileItem)
-{
-    ThumbBarItem* item = d->itemDict.find(fileItem->url().url());
+    ThumbBarItem* item = d->itemDict.find(url.url());
     if (!item)
         return;
 
@@ -786,7 +801,7 @@ void ThumbBarView::slotFailedPreview(const KFileItem* fileItem)
         delete item->d->pixmap;
         item->d->pixmap = 0;
     }
-    
+
     item->d->pixmap = new QPixmap(pix);
     item->repaint();
 }
@@ -892,7 +907,7 @@ void ThumbBarToolTip::maybeTip(const QPoint& pos)
 
     QRect r(item->rect());
     r = QRect( m_view->contentsToViewport(r.topLeft()), r.size() );
-    
+
     tip(r, tipText);
 }
 
@@ -942,7 +957,7 @@ QString ThumbBarToolTip::tipContent(ThumbBarItem* item)
         }
 
         QSize   dims;
-        QString rawFilesExt(raw_file_extentions);
+        QString rawFilesExt(KDcrawIface::DcrawBinary::instance()->rawFiles());
         QString ext = fileInfo.extension(false).upper();
 
         if (!ext.isEmpty() && rawFilesExt.upper().contains(ext))
@@ -1086,7 +1101,7 @@ QString ThumbBarToolTip::breakString(const QString& input)
 
     QString br;
 
-    uint i = 0;
+    uint i     = 0;
     uint count = 0;
 
     while (i < str.length())
@@ -1109,4 +1124,3 @@ QString ThumbBarToolTip::breakString(const QString& input)
 }
 
 }  // NameSpace Digikam
-
