@@ -7,7 +7,7 @@
  * Description : a widget to display a panel to choose
  *               a rectangular image area.
  *
- * Copyright (C) 2004-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -93,7 +93,7 @@ ImagePanIconWidget::~ImagePanIconWidget()
     delete d;
 }
 
-void ImagePanIconWidget::setHighLightPoints(QPointArray pointsList)
+void ImagePanIconWidget::setHighLightPoints(const QPointArray& pointsList)
 {
     d->hightlightPoints = pointsList;
     updatePixmap();
@@ -196,4 +196,3 @@ void ImagePanIconWidget::slotSeparateViewToggled(int t)
 }
 
 }  // NameSpace Digikam
-
