@@ -7,7 +7,7 @@
  * Description : camera icon view
  * 
  * Copyright (C) 2004-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -55,7 +55,6 @@
 #include "dpopupmenu.h"
 #include "dragobjects.h"
 #include "cameraui.h"
-#include "cameradragobject.h"
 #include "cameraiconitem.h"
 #include "cameraiconview.h"
 #include "cameraiconview.moc"
@@ -608,7 +607,7 @@ void CameraIconView::uploadItemPopupMenu(const KURL::List& srcURLs)
 {
     KPopupMenu popMenu(this);
     popMenu.insertTitle(SmallIcon("digikam"), d->cameraUI->cameraTitle());
-    popMenu.insertItem( SmallIcon("goto"), i18n("&Upload into camera"), 10 );
+    popMenu.insertItem( SmallIcon("goto"), i18n("&Upload to camera"), 10 );
     popMenu.insertSeparator(-1);
     popMenu.insertItem( SmallIcon("cancel"), i18n("C&ancel") );
 
@@ -692,17 +691,7 @@ void CameraIconView::updateItemRectsPixmap()
 
 void CameraIconView::slotThemeChanged()
 {
-    QPalette plt(palette());
-    QColorGroup cg(plt.active());
-    cg.setColor(QColorGroup::Base, ThemeEngine::instance()->baseColor());
-    cg.setColor(QColorGroup::Text, ThemeEngine::instance()->textRegColor());
-    cg.setColor(QColorGroup::HighlightedText, ThemeEngine::instance()->textSelColor());
-    plt.setActive(cg);
-    plt.setInactive(cg);
-    setPalette(plt);
-
     updateItemRectsPixmap();
-
     viewport()->update();
 }
 
